==> haskell-exceptions-0.8.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: exceptions
version: 0.8.3
id: exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT
key: exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT
license: BSD3
copyright: Copyright (C) 2013-2015 Edward A. Kmett
           Copyright (C) 2012 Google Inc.
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/exceptions/
synopsis: Extensible optionally-pure exceptions
description:
    Extensible optionally-pure exceptions
category: Control, Exceptions, Monad
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Catch Control.Monad.Catch.Pure
abi: f624bf973f8eeff6578fe95732b4e11a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/exceptions-0.8.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/exceptions-0.8.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/exceptions-0.8.3
hs-libraries: HSexceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    template-haskell-2.12.0.0 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html: /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exceptions-0.8.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: exceptions
version: 0.8.3
id: exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
key: exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
license: BSD3
copyright: Copyright (C) 2013-2015 Edward A. Kmett
           Copyright (C) 2012 Google Inc.
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/exceptions/
synopsis: Extensible optionally-pure exceptions
description:
    Extensible optionally-pure exceptions
category: Control, Exceptions, Monad
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Catch Control.Monad.Catch.Pure
abi: 349f1b5172af08123dc6c444b05979b3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/exceptions-0.8.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/exceptions-0.8.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/exceptions-0.8.3
hs-libraries: HSexceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    template-haskell-2.12.0.0 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html: /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
